/*--------------------------------------------------------------------
 * Copyright © 2016-2021 James Hunt <jamesodhunt@gmail.com>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *--------------------------------------------------------------------
 */

#ifndef _PROCENV_PLATFORM_DARWIN_H
#define _PROCENV_PLATFORM_DARWIN_H

#include "platform.h"
#include "util.h"

#include <mach/mach.h>
#include <mach-o/dyld.h>
#include <dlfcn.h>
#include <libgen.h>

#define mib_len(mib) ((sizeof (mib) / sizeof(*mib)) - 1)

#define mach_header_size(h) \
    (((h)->magic == MH_MAGIC_64 || (h)->magic == MH_CIGAM_64) \
        ? sizeof(struct mach_header_64) \
        : sizeof(struct mach_header))

#endif /* _PROCENV_PLATFORM_DARWIN_H */
